@@ -1,4 +1,17 @@
 package Term::ReadLine::Perl5::OO::State;
+=pod
+
+=head1 NAME
+
+Term::ReadLine::Perl5::OO:State
+
+=head1 DESCRIPTION
+
+Object to old the internal state of an editable line. Thas things like
+the text of the line and cursor position,
+
+=cut
+
 
 use Class::Accessor::Lite 0.05 (
     rw => [qw(buf pos cols prompt oldpos maxrows query)],
